@@ -17,9 +17,9 @@
 # Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 # Boston, MA 02111-1307, USA.
 
-__id__        = "$Id: J2SE-access-bridge.py 2554 2007-07-25 23:30:16Z lmonsanto $"
-__version__   = "$Revision: 2554 $"
-__date__      = "$Date: 2007-07-25 19:30:16 -0400 (Wed, 25 Jul 2007) $"
+__id__        = "$Id: J2SE-access-bridge.py 2719 2007-08-26 18:52:54Z joanied $"
+__version__   = "$Revision: 2719 $"
+__date__      = "$Date: 2007-08-26 14:52:54 -0400 (Sun, 26 Aug 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -36,6 +36,7 @@ import Accessibility
 import speechgenerator
 
 from orca_i18n import _ # for gettext support
+from orca_i18n import Q_ # to provide qualified translatable strings
 
 ########################################################################
 #                                                                      #
@@ -78,11 +79,19 @@ class SpeechGenerator(speechgenerator.SpeechGenerator):
             #
             utterances.append(_("collapsed"))
         elif obj.state.count(Accessibility.STATE_SELECTED) != 0:
-            utterances.append(_("selected"))
+            # Translators: this represents the state of a node in a tree
+            # or list.
+            #
+            # ONLY TRANSLATE THE PART AFTER THE PIPE CHARACTER |
+            utterances.append(Q_("listitem|selected"))
             obj.was_selected = True
         elif obj.state.count(Accessibility.STATE_SELECTED) == 0 and \
                 obj.state.count(Accessibility.STATE_SELECTABLE) != 0:
-            utterances.append(_("unselected"))
+            # Translators: this represents the state of a node in a tree
+            # or list.
+            #
+            # ONLY TRANSLATE THE PART AFTER THE PIPE CHARACTER |
+            utterances.append(Q_("listitem|unselected"))
 
         self._debugGenerator("_getSpeechForLabel",
                              obj,
