@@ -19,9 +19,9 @@
 
 """Provides the interface to the AT-SPI Registry."""
 
-__id__        = "$Id: atspi.py 2503 2007-06-26 20:25:55Z lmonsanto $"
-__version__   = "$Revision: 2503 $"
-__date__      = "$Date: 2007-06-26 16:25:55 -0400 (Tue, 26 Jun 2007) $"
+__id__        = "$Id: atspi.py 2721 2007-08-26 20:07:53Z joanied $"
+__version__   = "$Revision: 2721 $"
+__date__      = "$Date: 2007-08-26 16:07:53 -0400 (Sun, 26 Aug 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -788,6 +788,8 @@ class Accessible:
             stateString += "HORIZONTAL "
         if stateSet.count(Accessibility.STATE_ICONIFIED):
             stateString += "ICONIFIED "
+        if stateSet.count(Accessibility.STATE_IS_DEFAULT):
+            stateString += "IS_DEFAULT "
         if stateSet.count(Accessibility.STATE_MODAL):
             stateString += "MODAL "
         if stateSet.count(Accessibility.STATE_MULTI_LINE):
