@@ -23,9 +23,9 @@ MouseButtonEvent, MouseMotionEvent, and SpeechEvent), and also provides a
 InputEventHandler class.  It is intended that instances of InputEventHandler
 will be used which should be used to handle all input events."""
 
-__id__        = "$Id: input_event.py,v 1.15 2006/10/05 16:31:03 wwalker Exp $"
-__version__   = "$Revision: 1.15 $"
-__date__      = "$Date: 2006/10/05 16:31:03 $"
+__id__        = "$Id: input_event.py 2437 2007-05-31 12:41:26Z wwalker $"
+__version__   = "$Revision: 2437 $"
+__date__      = "$Date: 2007-05-31 08:41:26 -0400 (Thu, 31 May 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -146,6 +146,10 @@ class InputEventHandler:
         self._description = description
         self._learnModeEnabled = learnModeEnabled
 
+    def __eq__(self, other):
+        """Compares one input handler to another."""
+        return (self._function == other._function)
+
     def processInputEvent(self, script, inputEvent):
         """Processes an input event.  If settings.learnModeEnabled is True,
         this will merely report the description of the input event to braille
