@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2004-2006 Sun Microsystems Inc.
+# Copyright 2004-2007 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -27,12 +27,14 @@ The following script specific key sequences are supported:
   Insert-[1-9]  -  Speak and braille a previous chat room message.
 """
 
-__id__        = "$Id: gaim.py 1584 2006-10-19 18:16:54Z richb $"
-__version__   = "$Revision: 1584 $"
-__date__      = "$Date: 2006-10-19 14:16:54 -0400 (Thu, 19 Oct 2006) $"
-__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__id__        = "$Id: gaim.py 2748 2007-09-01 18:56:48Z joanied $"
+__version__   = "$Revision: 2748 $"
+__date__      = "$Date: 2007-09-01 14:56:48 -0400 (Sat, 01 Sep 2007) $"
+__copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
+import gtk
+
 import orca.atspi as atspi
 import orca.braille as braille
 import orca.debug as debug
@@ -42,10 +44,13 @@ import orca.keybindings as keybindings
 import orca.rolenames as rolenames
 import orca.settings as settings
 import orca.speech as speech
-import orca.util as util
 
 from orca.orca_i18n import _
 
+# Whether we prefix chat room messages with the name of the chat room.
+#
+prefixChatMessage = False
+
 ########################################################################
 #                                                                      #
 # Ring List. A fixed size circular list by Flavio Catalani             #
@@ -107,10 +112,6 @@ class Script(default.Script):
         #
         self.debugLevel = debug.LEVEL_FINEST
 
-        # Whether we prefix chat room messages with the name of the chat room.
-        #
-        self.prefixChatMessage = False
-
         # Create two cyclic lists; one that will contain the previous
         # chat room messages and the other that will contain the names
         # of the associated chat rooms.
@@ -149,7 +150,10 @@ class Script(default.Script):
                 Script.togglePrefix,
                 _("Toggle whether we prefix chat room messages with the name of the chat room."))
 
-        self.inputEventHandlers["readPreviousMessageHandler"] = \
+        # In gaim/pidgin, we are overriding the default script's bookmark
+        # feature and keybindings to provide chat room message history.
+        #
+        self.inputEventHandlers["goToBookmark"] = \
             input_event.InputEventHandler(
                 Script.readPreviousMessage,
                 _("Speak and braille a previous chat room message."))
@@ -172,17 +176,82 @@ class Script(default.Script):
                 1 << settings.MODIFIER_ORCA,
                 self.inputEventHandlers["togglePrefixHandler"]))
 
+        # In gaim/pidgin, we are overriding the default script's bookmark
+        # feature and keybindings to provide chat room message history.
+        #
         messageKeys = [ "1", "2", "3", "4", "5", "6", "7", "8", "9" ]
-        for i in range(0, len(messageKeys)):
+        for messageKey in messageKeys:
             keyBindings.add(
                 keybindings.KeyBinding(
-                    messageKeys[i],
+                    messageKey,
                     1 << settings.MODIFIER_ORCA,
                     1 << settings.MODIFIER_ORCA,
-                    self.inputEventHandlers["readPreviousMessageHandler"]))
+                    self.inputEventHandlers["goToBookmark"]))
 
         return keyBindings
 
+    def getAppPreferencesGUI(self):
+        """Return a GtkVBox contain the application unique configuration
+        GUI items for the current application.
+        """
+
+        global prefixChatMessage
+
+        vbox = gtk.VBox(False, 0)
+        vbox.set_border_width(12)
+        gtk.Widget.show(vbox)
+        # Translators: If this checkbox is checked, then Orca will speak
+        # the name of the chat room.
+        #
+        label = _("Speak Chat Room name")
+        self.speakNameCheckButton = gtk.CheckButton(label)
+        gtk.Widget.show(self.speakNameCheckButton)
+        gtk.Box.pack_start(vbox, self.speakNameCheckButton, False, False, 0)
+        gtk.ToggleButton.set_active(self.speakNameCheckButton,
+                                    prefixChatMessage)
+
+        return vbox
+
+    def setAppPreferences(self, prefs):
+        """Write out the application specific preferences lines and set the
+        new values.
+
+        Arguments:
+        - prefs: file handle for application preferences.
+        """
+
+        global prefixChatMessage
+
+        prefixChatMessage = self.speakNameCheckButton.get_active()
+        prefs.writelines("\n")
+        prefs.writelines("orca.scripts.gaim.prefixChatMessage = %s\n" % \
+                         prefixChatMessage)
+
+    def getAppState(self):
+        """Returns an object that can be passed to setAppState.  This
+        object will be use by setAppState to restore any state information
+        that was being maintained by the script."""
+        return [default.Script.getAppState(self),
+                self.previousMessages,
+                self.previousChatRoomNames,
+                self.chatAreas]
+
+    def setAppState(self, appState):
+        """Sets the application state using the given appState object.
+
+        Arguments:
+        - appState: an object obtained from getAppState
+        """
+        try:
+            [defaultAppState,
+             self.previousMessages,
+             self.previousChatRoomNames,
+             self.chatAreas] = appState
+            default.Script.setAppState(self, defaultAppState)
+        except:
+            debug.printException(debug.LEVEL_WARNING)
+            pass
+
     def togglePrefix(self, inputEvent):
         """ Toggle whether we prefix chat room messages with the name of
         the chat room.
@@ -191,11 +260,13 @@ class Script(default.Script):
         - inputEvent: if not None, the input event that caused this action.
         """
 
+        global prefixChatMessage
+
         debug.println(self.debugLevel, "gaim.togglePrefix.")
 
         line = _("speak chat room name.")
-        self.prefixChatMessage = not self.prefixChatMessage
-        if not self.prefixChatMessage:
+        prefixChatMessage = not prefixChatMessage
+        if not prefixChatMessage:
             line = _("Do not speak chat room name.")
 
         speech.speak(line)
@@ -211,10 +282,12 @@ class Script(default.Script):
         - message: the chat room message.
         """
 
+        global prefixChatMessage
+
         text = ""
-        if self.prefixChatMessage:
+        if prefixChatMessage:
             if chatRoomName and chatRoomName != "":
-                text += _("Message from chat room ") + chatRoomName + " "
+                text += _("Message from chat room %s") % chatRoomName + " "
         if message and message != "":
             text += message
 
@@ -305,8 +378,9 @@ class Script(default.Script):
             # text field. Hopefully this is true for other types of chat
             # as well, but is currently untested.
             #
-            allTextFields = util.findByRole(chatRoomTab,
-                                            rolenames.ROLE_TEXT)
+            allTextFields = self.findByRole(chatRoomTab,
+                                            rolenames.ROLE_TEXT,
+                                            False)
             index = len(allTextFields) - 2
             if index >= 0:
                 self.chatAreas[chatRoomTab] = allTextFields[index]
@@ -327,7 +401,13 @@ class Script(default.Script):
             if message and message[0] == "\n":
                 message = message[1:]
 
-            chatRoomName = util.getDisplayedText(chatRoomTab)
+            chatRoomName = self.getDisplayedText(chatRoomTab)
+
+            # If the new message came from the room with focus, we don't
+            # want to speak its name even if prefixChatMessage is enabled.
+            #
+            if event.source.state.count(atspi.Accessibility.STATE_SHOWING):
+                chatRoomName = ""
             self.utterMessage(chatRoomName, message)
 
             # Add the latest message to the list of saved ones. For each
