@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2004-2006 Sun Microsystems Inc.
+# Copyright 2004-2007 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -20,17 +20,21 @@
 """Manages the default speech server for orca.  A script can use this
 as its speech server, or it can feel free to create one of its own."""
 
-__id__        = "$Id: speech.py,v 1.60 2006/08/11 17:24:24 wwalker Exp $"
-__version__   = "$Revision: 1.60 $"
-__date__      = "$Date: 2006/08/11 17:24:24 $"
-__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__id__        = "$Id: speech.py 2548 2007-07-21 21:46:43Z wwalker $"
+__version__   = "$Revision: 2548 $"
+__date__      = "$Date: 2007-07-21 17:46:43 -0400 (Sat, 21 Jul 2007) $"
+__copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
+import logging
+log = logging.getLogger("speech")
+
 import time
 
 import debug
+import keynames
+import orca
 import orca_state
-import platform
 import settings
 
 from acss import ACSS
@@ -38,7 +42,7 @@ from orca_i18n import _           # for gettext support
 
 # The speech server to use for all speech operations.
 #
-__speechserver = None
+_speechserver = None
 
 def getSpeechServerFactories():
     """Imports all known SpeechServer factory modules.  Returns a list
@@ -63,9 +67,9 @@ def getSpeechServerFactories():
 
 def init():
 
-    global __speechserver
+    global _speechserver
 
-    if __speechserver:
+    if _speechserver:
         return
 
     # First, find the factory module to use.  We will
@@ -103,9 +107,9 @@ def init():
     #
     speechServerInfo = settings.speechServerInfo
     if speechServerInfo:
-        __speechserver = factory.SpeechServer.getSpeechServer(speechServerInfo)
+        _speechserver = factory.SpeechServer.getSpeechServer(speechServerInfo)
     else:
-        __speechserver = factory.SpeechServer.getSpeechServer()
+        _speechserver = factory.SpeechServer.getSpeechServer()
 
 def __resolveACSS(acss=None):
     if acss:
@@ -117,8 +121,13 @@ def __resolveACSS(acss=None):
 def sayAll(utteranceIterator, progressCallback):
     if settings.silenceSpeech:
         return
-    if __speechserver:
-        __speechserver.sayAll(utteranceIterator, progressCallback)
+    if _speechserver:
+        _speechserver.sayAll(utteranceIterator, progressCallback)
+    else:
+        for [context, acss] in utteranceIterator:
+            debug.println(debug.LEVEL_INFO,
+                          "SPEECH OUTPUT: '" + context.utterance + "'")
+            log.info("sayAll utterance='%s'" % context.utterance)
 
 def speak(text, acss=None, interrupt=True):
     """Speaks all queued text immediately.  If text is not None,
@@ -145,14 +154,49 @@ def speak(text, acss=None, interrupt=True):
         return
 
     debug.println(debug.LEVEL_INFO, "SPEECH OUTPUT: '" + text + "'")
+    log.info("speak utterance='%s'" % text)
 
-    if __speechserver:
-        __speechserver.speak(text, __resolveACSS(acss), interrupt)
+    if _speechserver:
+        _speechserver.speak(text, __resolveACSS(acss), interrupt)
+
+def speakKeyEvent(event_string, type):
+    """Speaks a key event immediately.
+
+    Arguments:
+    - event_string: string representing the key event as defined by
+                    input_event.KeyboardEvent.
+    - type:         key event type as one of orca.KeyEventType constants.
+
+    """
+    if settings.silenceSpeech:
+        return
+
+    if _speechserver:
+        _speechserver.speakKeyEvent(event_string, type)
+    else:
+        # Check to see if there are localized words to be spoken for
+        # this key event.
+        #
+        event_string = keynames.getKeyName(event_string)
+
+        if type == orca.KeyEventType.LOCKING_LOCKED:
+            # Translators: this represents the state of a locking modifier
+            # key (e.g., Caps Lock)
+            #
+            event_string += " " + _("on")
+        elif type == orca.KeyEventType.LOCKING_UNLOCKED:
+            # Translators: this represents the state of a locking modifier
+            # key (e.g., Caps Lock)
+            #
+            event_string += " " + _("off")
+
+        debug.println(debug.LEVEL_INFO, "SPEECH OUTPUT: '" + event_string +"'")
+        log.info("speakKeyEvent utterance='%s'" % event_string)
 
 def isSpeaking():
     """"Returns True if the system is currently speaking."""
-    if __speechserver:
-        return __speechserver.isSpeaking()
+    if _speechserver:
+        return _speechserver.isSpeaking()
     else:
         return False
 
@@ -181,46 +225,67 @@ def speakUtterances(utterances, acss=None, interrupt=True):
     for utterance in utterances:
         debug.println(debug.LEVEL_INFO,
                       "SPEECH OUTPUT: '" + utterance + "'")
+        log.info("speakUtterances utterance='%s'" % utterance)
 
-    if __speechserver:
-        __speechserver.speakUtterances(utterances,
+    if _speechserver:
+        _speechserver.speakUtterances(utterances,
                                        __resolveACSS(acss),
                                        interrupt)
 
 def stop():
-    if __speechserver:
-        __speechserver.stop()
+    if _speechserver:
+        _speechserver.stop()
 
 def increaseSpeechRate(script=None, inputEvent=None):
-    if __speechserver:
-        __speechserver.increaseSpeechRate()
+    if _speechserver:
+        _speechserver.increaseSpeechRate()
+    else:
+        debug.println(debug.LEVEL_INFO,
+                      "SPEECH OUTPUT: 'faster'")
+        log.info("increaseSpeechRate")
+
     return True
 
 def decreaseSpeechRate(script=None, inputEvent=None):
-    if __speechserver:
-        __speechserver.decreaseSpeechRate()
+    if _speechserver:
+        _speechserver.decreaseSpeechRate()
+    else:
+        debug.println(debug.LEVEL_INFO,
+                      "SPEECH OUTPUT: 'slower'")
+        log.info("decreaseSpeechRate")
+
     return True
 
 def increaseSpeechPitch(script=None, inputEvent=None):
-    if __speechserver:
-        __speechserver.increaseSpeechPitch()
+    if _speechserver:
+        _speechserver.increaseSpeechPitch()
+    else:
+        debug.println(debug.LEVEL_INFO,
+                      "SPEECH OUTPUT: 'higher'")
+        log.info("increaseSpeechPitch")
+
     return True
 
 def decreaseSpeechPitch(script=None, inputEvent=None):
-    if __speechserver:
-        __speechserver.decreaseSpeechPitch()
+    if _speechserver:
+        _speechserver.decreaseSpeechPitch()
+    else:
+        debug.println(debug.LEVEL_INFO,
+                      "SPEECH OUTPUT: 'lower'")
+        log.info("decreaseSpeechPitch")
+
     return True
 
 def shutdown():
-    global __speechserver
-    if __speechserver:
-        __speechserver.shutdownActiveServers()
-        __speechserver = None
+    global _speechserver
+    if _speechserver:
+        _speechserver.shutdownActiveServers()
+        _speechserver = None
 
 def reset(text=None, acss=None):
-    global __speechserver
-    if __speechserver:
-        __speechserver.reset(text, acss)
+    global _speechserver
+    if _speechserver:
+        _speechserver.reset(text, acss)
 
 def testNoSettingsInit():
     init()
