@@ -23,9 +23,9 @@ class.  For those wishing to override the speech generators, however,
 one can create a new instance and replace/extend the speech generators
 as they see fit."""
 
-__id__        = "$Id: speechgenerator.py 2719 2007-08-26 18:52:54Z joanied $"
-__version__   = "$Revision: 2719 $"
-__date__      = "$Date: 2007-08-26 14:52:54 -0400 (Sun, 26 Aug 2007) $"
+__id__        = "$Id: speechgenerator.py 2750 2007-09-01 19:15:08Z joanied $"
+__version__   = "$Revision: 2750 $"
+__date__      = "$Date: 2007-09-01 15:15:08 -0400 (Sat, 01 Sep 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -37,8 +37,9 @@ import orca_state
 import rolenames
 import settings
 
-from orca_i18n import _   # for gettext support
-from orca_i18n import Q_  # to provide qualified translatable strings
+from orca_i18n import _         # for gettext support
+from orca_i18n import ngettext  # for ngettext support
+from orca_i18n import Q_        # to provide qualified translatable strings
 
 class SpeechGenerator:
     """Takes accessible objects and produces a string to speak for
@@ -1312,9 +1313,6 @@ class SpeechGenerator:
         utterances.append(self._script.getDisplayedText(\
                           self._script.getRealActiveDescendant(obj)))
 
-        # [[[TODO: WDW - HACK attempt to determine if this is a node;
-        # if so, describe its state.]]]
-        #
         if obj.state.count(atspi.Accessibility.STATE_EXPANDABLE):
             if obj.state.count(atspi.Accessibility.STATE_EXPANDED):
                 # Translators: this represents the state of a node in a tree.
@@ -1322,6 +1320,19 @@ class SpeechGenerator:
                 # 'collapsed' means the children are not showing.
                 #
                 utterances.append(_("expanded"))
+                childNodes = self._script.getChildNodes(obj)
+                children = len(childNodes)
+
+                if not children \
+                   or (settings.speechVerbosityLevel == \
+                       settings.VERBOSITY_LEVEL_VERBOSE):
+                    # Translators: this is the number of items in a layered
+                    # pane or table.
+                    #
+                    itemString = ngettext("%d item",
+                                          "%d items",
+                                          children) % children
+                    utterances.append(itemString)
             else:
                 # Translators: this represents the state of a node in a tree.
                 # 'expanded' means the children are showing.
@@ -1329,15 +1340,6 @@ class SpeechGenerator:
                 #
                 utterances.append(_("collapsed"))
 
-            # If this is an expandable table cell with no children, then
-            # let the user know.
-            #
-            if obj.childCount == 0:
-                # Translators: this is the number of items in a layered pane
-                # or table.
-                #
-                utterances.append(_("0 items"))
-
         self._debugGenerator("_getSpeechForTableCell",
                              obj,
                              already_focused,
